package com.proyek.akhir.kodel.ui.user.dashboard

import android.content.Intent
import android.os.Build
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.lifecycle.Observer
import androidx.lifecycle.ViewModelProvider
import androidx.recyclerview.widget.LinearLayoutManager
import com.proyek.akhir.kodel.R
import com.proyek.akhir.kodel.data.local.Berita
import com.proyek.akhir.kodel.data.local.Penunggak
import com.proyek.akhir.kodel.data.response.AnggotaItem
import com.proyek.akhir.kodel.data.response.BeritaItem
import com.proyek.akhir.kodel.data.response.UtangItem
import com.proyek.akhir.kodel.ui.user.dashboard.ajuanPinjaman.AjuanPinjamanActivity
import com.proyek.akhir.kodel.ui.user.dashboard.detailPenunggak.DetailPenunggakActivity
import com.proyek.akhir.kodel.ui.user.dashboard.history.HistoryActivity
import com.proyek.akhir.kodel.ui.user.dashboard.isiSaldo.IsiSaldoActivity
import com.proyek.akhir.kodel.ui.user.dashboard.tarikSaldo.TarikSaldoActivity
import kotlinx.android.synthetic.main.fragment_dashboard.*
import kotlinx.android.synthetic.main.fragment_dashboard.view.*
import java.text.SimpleDateFormat
import java.util.*
import java.util.concurrent.TimeUnit
import kotlin.collections.ArrayList


class DashboardFragment : Fragment() {
    private val listPenunggak: MutableList<Penunggak> = mutableListOf()
    private lateinit var penunggakDashboardAdapter: PenunggakDashboardAdapter

    private lateinit var dashboardViewModel: DashboardViewModel

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        dashboardViewModel =
            ViewModelProvider(this).get(DashboardViewModel::class.java)
        val root = inflater.inflate(R.layout.fragment_dashboard, container, false)

        root.dashboardLoading.visibility = View.VISIBLE

        root.lnrUtang.visibility = View.GONE
        root.txtNameHallo.visibility = View.GONE
        root.pengingatPenunggak.visibility = View.GONE

        root.rvPenunggakBeranda.setHasFixedSize(true)

        listPenunggak.addAll(getListPenunggak())

        root.rvPenunggakBeranda.layoutManager =
            LinearLayoutManager(activity, LinearLayoutManager.VERTICAL, false)


        penunggakDashboardAdapter = PenunggakDashboardAdapter(listPenunggak)
        root.rvPenunggakBeranda.adapter = penunggakDashboardAdapter

        root.isiSaldoDashboard.setOnClickListener {
            startActivity(Intent(activity, IsiSaldoActivity::class.java))
        }

        root.tarikSaldoDashboard.setOnClickListener {
            startActivity(Intent(activity, TarikSaldoActivity::class.java))
        }

        root.historyBellButton.setOnClickListener {
            startActivity(Intent(activity, HistoryActivity::class.java))
        }

        root.detailPenunggak.setOnClickListener {
            startActivity(Intent(activity, DetailPenunggakActivity::class.java))
        }

        root.ajuanPinjamDashboard.setOnClickListener {
            startActivity(Intent(activity, AjuanPinjamanActivity::class.java))
        }

        root.refreshDashboardUser.setOnRefreshListener {
            root.refreshDashboardUser.isRefreshing = true
            callAnggota()
            callUtang()
            callBerita()
        }

        callAnggota()

        callUtang()

        return root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        rvBeritaKabarDashboard.setHasFixedSize(true)

        rvBeritaKabarDashboard.layoutManager =
            LinearLayoutManager(activity, LinearLayoutManager.HORIZONTAL, false)

        callBerita()

    }

    private fun getListPenunggak(): ArrayList<Penunggak> {
        val dataImage = resources.obtainTypedArray(R.array.img_penunggak)
        val dataName = resources.getStringArray(R.array.name_penunggak)
        val dataHari = resources.getStringArray(R.array.hari_penunggak)

        val listPenunggakAll = ArrayList<Penunggak>()
        listPenunggak.clear()
        for (i in 0 until dataImage.length()) {
            val penunggak = Penunggak(
                dataImage.getResourceId(i, 0),
                dataName[i],
                dataHari[i]
            )
            listPenunggakAll.add(penunggak)
        }
        dataImage.recycle()
        return listPenunggakAll
    }


    private fun callAnggota() {
        dashboardViewModel = ViewModelProvider(this).get(DashboardViewModel::class.java)
        dashboardViewModel.setDataAnggota().observe(viewLifecycleOwner, Observer { item ->
            showData(item)
        })
    }

    private fun callUtang() {
        dashboardViewModel = ViewModelProvider(this).get(DashboardViewModel::class.java)
        dashboardViewModel.setDataUtang().observe(viewLifecycleOwner, Observer { utang ->
            if (utang[0].tglPinjam != null) {
                lnrUtang.visibility = View.VISIBLE
                showUtang(utang)
            } else {
                lnrUtang.visibility = View.GONE
            }
        })
    }

    private fun callBerita() {
        dashboardViewModel = ViewModelProvider(this).get(DashboardViewModel::class.java)
        dashboardViewModel.setDataBerita().observe(viewLifecycleOwner, Observer { berita ->
            if (berita != null) {
                showBerita(berita)
                dashboardLoading.visibility = View.GONE
                refreshDashboardUser.isRefreshing = false
            } else {
                lnrBeritaKabar.visibility = View.GONE
                rvBeritaKabarDashboard.visibility = View.GONE
                refreshDashboardUser.isRefreshing = false
            }
        })
    }


    private fun showUtang(utang: List<UtangItem>) {

        sisaUtang.text = getString(R.string.sisa_utang_value, utang[0].jlhUtang)

        if (utang[0].isMenunggak) {
            pengingatPenunggak.visibility = View.VISIBLE
        }

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
//                val current = LocalDateTime.now()
//                val formatter = DateTimeFormatter.ofPattern("dd.MM.yyyy. HH:mm:ss")
//                var answer: String = current.format(formatter)

        } else {
            val date: Date = Calendar.getInstance().time
            val inputFormatter = SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ssZ")
//                val outputFormatter = SimpleDateFormat("dd-MM-yyyy")
//                val answer = inputFormatter.format(date)

            val datePinjamApi = inputFormatter.parse(utang[0].tglPinjam)

            val millionSeconds = datePinjamApi?.time?.minus(Calendar.getInstance().timeInMillis)

            if (millionSeconds!! <= 0) {
                keteranganUtang.text = "Menunggak"
                jatuhtempUtang.text = getString(
                    R.string.hari_lagi,
                    millionSeconds.let { TimeUnit.MILLISECONDS.toDays(it).toString() })
            } else {
                keteranganUtang.text = "Jatuh Tempo"
                jatuhtempUtang.text = getString(
                    R.string.hari_lagi,
                    millionSeconds.let { TimeUnit.MILLISECONDS.toDays(it).toString() })
            }
        }
    }

    private fun showData(anggota: List<AnggotaItem>) {
        saldoUser.text = getString(R.string.saldo_user_value, anggota[0].saldoAnggota)

        //Nama Anggota
        var name = anggota[0].namaAnggota
        val arr: Array<String> = name.split(" ").toTypedArray()
        val firstWord = arr[0]
        txtNameHallo.visibility = View.VISIBLE
        txtNameHallo.text = getString(R.string.halo_name, firstWord)
    }

    private fun showBerita(berita: List<BeritaItem>) {
        rvBeritaKabarDashboard.adapter = BeritaDashboardAdapter(berita)
    }


}
